==> owncloud-8.1.0p2.tgz: owncloud/lib/l10n/es_MX.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "¡No se puede escribir en el directorio «config»!\n\nNormalmente esto se soluciona dándole al servidor web acceso para escribir en el directorio config. \n\nConfiguración de muestra detectado",
    "See %s" : "ver %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Normalmente esto se soluciona %s dándole al servidor web acceso para escribir en el directorio config %s",
    "Sample configuration detected" : "Configuración de muestra detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se detectó que la configuración de muestra se había copiado. Esto puede romper su instalacón y no está respaldado. Por favor lea la documentación antes de realizar cambios en la config.php",
    "Help" : "Ayuda",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Admin" : "Administración",
    "No app name specified" : "No se ha especificado nombre de la aplicación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "today" : "hoy",
    "yesterday" : "ayer",
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "año pasado",
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "web services under your control" : "Servicios web bajo su control",
    "App directory already exists" : "El directorio de la aplicación ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
    "No source specified when installing app" : "No se ha especificado origen cuando se ha instalado la aplicación",
    "No href specified when installing app from http" : "No href especificado cuando se ha instalado la aplicación",
    "No path specified when installing app from local file" : "Sin path especificado cuando se ha instalado la aplicación desde el archivo local",
    "Archives of type %s are not supported" : "Archivos de tipo %s no son soportados",
    "Failed to open archive when installing app" : "Fallo de abrir archivo mientras se instala la aplicación",
    "App does not provide an info.xml file" : "La aplicación no suministra un archivo info.xml",
    "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "La aplicación no puede ser instalada por que la versión en info.xml/version no es la misma que la establecida en la app store",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token expirado. Por favor, recarga la página.",
    "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
    "MS SQL username and/or password not valid: %s" : "Usuario y/o contraseña de MS SQL no válidos: %s",
    "You need to enter either an existing account or the administrator." : "Tiene que ingresar una cuenta existente o la del administrador.",
    "DB Error: \"%s\"" : "Error BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comando infractor: \"%s\"",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
    "Offending command was: \"%s\", name: %s, password: %s" : "Comando infractor: \"%s\", nombre: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "%s shared »%s« with you" : "%s ha compartido  »%s« contigo",
    "Could not find category \"%s\"" : "No puede encontrar la categoria \"%s\"",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/es_MX.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡No se puede escribir en el directorio «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "¡No se puede escribir en el directorio «config»!\n\nNormalmente esto se soluciona dándole al servidor web acceso para escribir en el directorio config. \n\nConfiguración de muestra detectado",
    "See %s" : "ver %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Normalmente esto se soluciona %s dándole al servidor web acceso para escribir en el directorio config %s",
    "Sample configuration detected" : "Configuración de muestra detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se detectó que la configuración de muestra se había copiado. Esto puede romper su instalacón y no está respaldado. Por favor lea la documentación antes de realizar cambios en la config.php",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "today" : "hoy",
    "yesterday" : "ayer",
    "last month" : "mes pasado",
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
    "last year" : "año pasado",
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
    "seconds ago" : "hace segundos",
    "None" : "Ninguno",
    "Username and password" : "Nombre de usuario y contraseña",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "File name contains at least one invalid character" : "Nombre de archivo contiene al menos un caracter no válido",
    "App directory already exists" : "El directorio de la aplicación ya existe",
    "Can't create app folder. Please fix permissions. %s" : "No se puede crear la carpeta de la aplicación. Corrija los permisos. %s",
    "No source specified when installing app" : "No se ha especificado origen cuando se ha instalado la aplicación",
    "No href specified when installing app from http" : "No href especificado cuando se ha instalado la aplicación",
    "No path specified when installing app from local file" : "Sin path especificado cuando se ha instalado la aplicación desde el archivo local",
    "Archives of type %s are not supported" : "Archivos de tipo %s no son soportados",
    "Failed to open archive when installing app" : "Fallo de abrir archivo mientras se instala la aplicación",
    "App does not provide an info.xml file" : "La aplicación no suministra un archivo info.xml",
    "App can't be installed because of not allowed code in the App" : "La aplicación no puede ser instalada por tener código no autorizado en la aplicación",
    "App can't be installed because it is not compatible with this version of ownCloud" : "La aplicación no se puede instalar porque no es compatible con esta versión de ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "La aplicación no se puede instalar porque contiene la etiqueta\n<shipped>\ntrue\n</shipped>\nque no está permitida para aplicaciones no distribuidas",
    "Apps" : "Aplicaciones",
    "General" : "General",
    "Storage" : "Almacenamiento",
    "Security" : "Seguridad",
    "Encryption" : "Cifrado",
    "Sharing" : "Compartir",
    "Search" : "Buscar",
    "Updates" : "Actualizaciones",
    "%s enter the database username." : "%s ingresar el usuario de la base de datos.",
    "%s enter the database name." : "%s ingresar el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
    "DB Error: \"%s\"" : "Error BD: \"%s\"",
    "Offending command was: \"%s\"" : "Comando infractor: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Tiene que ingresar una cuenta existente o la del administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Comando infractor: \"%s\", nombre: %s, contraseña: %s",
    "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "Invalid Federated Cloud ID" : "ID de Nube Federada Inválida",
    "%s shared »%s« with you" : "%s ha compartido  »%s« contigo",
    "Sharing %s failed, because this item is already shared with %s" : "No se puedo compartir %s, porque este elemento ya está compartido con %s",
    "Not allowed to create a federated share with the same user" : "No está permitido compartir de forma federada con el mismo usuario",
    "Could not find category \"%s\"" : "No puede encontrar la categoria \"%s\"",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "Help" : "Ayuda",
    "Settings" : "Configuración",
    "Users" : "Usuarios",
    "web services under your control" : "Servicios web bajo su control",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token expirado. Por favor, recarga la página.",
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
    "A safe home for all your data" : "Un lugar seguro para todos tus datos",
    "Imprint" : "pie de imprenta",
    "__language_name__" : "Español (México)"
},
"nplurals=2; plural=(n != 1);");
